<!--空气监测 -->
<template>
    <div class="page-top">
        <div class="page-top-left">
            <DeviceImage :typeId="1411" :devIns="deviceIns"/>
            <div style="height: 230px; width: 100%; margin-top: 16px;">
                <DeviceInfo :ndata="ndata"/>
            </div>
        </div>
        <div class="page-top-right">
            <div class="page-top-right-top">
                <DeviceRuningStatus :propertyValue="propertyValue" @propertyClick="queryChartsAggList"/>
            </div>
            <div class="page-top-right-bottom">
                    <EnvironmentalCurve :cdata="chartValue"/>
            </div>
        </div>
    </div>
    <div class="page-bottom">
        <WarningInfo :deviceId="props?.ndata?.deviceId"/>
    </div>
</template>
<script lang="ts" name="KQJC" setup>
import DeviceInfo from '../components/DeviceInfo.vue';
import DeviceImage from '../components/DeviceImage.vue';
import EnvironmentalCurve from '../components/EnvironmentalCurve.vue';
import WarningInfo from '../components/WarningInfo.vue';
import DeviceRuningStatus from '../components/DeviceRuningStatus.vue';

import { getWebSocket } from '@/utils/websocket';
import { map } from 'rxjs/operators';

const props = defineProps({
    ndata: {
        type: Object,
        default: () => {}
    }
});

import { detail } from '@/api/device/instance'
import { DeviceInstance,PropertyData } from "@/views/device/Instance/typings"
const deviceIns = ref<DeviceInstance>();
const metadata = ref<Record<string, any>>({});
const propertyValue = ref<Record<string, any>>({});
const loadDevIns = async ()=>{
    const resp: any = await detail(props.ndata.deviceId)
    if(resp.status === 200){
        deviceIns.value =  resp.result
        metadata.value = JSON.parse(deviceIns.value?.metadata || '{}');
        //propertyValue.value = metadata.value.properties;
        if(metadata.value.properties){
            metadata.value.properties.forEach((p:any)=>{
                propertyValue.value[p.id] = p
            })
        }
        subscribeProperty();
        if(metadata.value?.properties.length>0){
            queryChartsAggList(metadata.value.properties[0]);
        }
    }   
}

onMounted(() => {
    loadDevIns();
});

const subRef = ref();
const dataSource = ref<PropertyData[]>([]);
const subscribeProperty = () =>{
    const id = `instance-info-property-${deviceIns.value?.id}-${
        deviceIns.value?.productId
    }-${metadata?.value?.properties.map((i: Record<string, any>) => i.id).join('-')}`;
    const topic = `/dashboard/device/${deviceIns.value?.productId}/properties/realTime`;
    subRef.value = getWebSocket(id, topic, {
        deviceId: deviceIns.value?.id,
        properties: dataSource.value.map((i: Record<string, any>) => i.id),
        history: 1,
    })
        ?.pipe(map((res: any) => res.payload))
        .subscribe((payload) => {      
            //console.log(payload?.value?.property+"================",payload)     
            if(propertyValue.value[payload?.value?.property]){
                propertyValue.value[payload?.value?.property] = {
                            ...propertyValue.value[payload?.value?.property],
                            ...payload
                        };            
            }
        });
};



//图表数据
import { getRangeTime } from '@/utils/utils';
import { getPropertiesInfo } from '@/api/device/instance';
const chartValue = ref<Record<string, any>>({});
const queryChartsAggList = async (property:any) => {
    const d = getRangeTime('week');
    const resp = await getPropertiesInfo(deviceIns.value?.id+'', {
        columns: [
            {
                property: property.id,
                alias: property.id,
                agg: 'MAX',
            }
        ],
        query: {
            interval: '1d',
            //format: 'yyyy-MM-dd HH:mm:ss',
            format: 'yyyy-MM-dd',
            from: d[0],
            to: d[1],
        }
    });
    if (resp.status === 200) {
        const dataList: any[] = [];
        (resp.result as any[]).forEach((i: any) => {
            dataList.push([i.time,Number(i[property.id])]);
        });  
        dataList.sort((a,b)=>{
            return a[0]>b[0]?1:-1;
        });     
        chartValue.value = {
            title:'近期环境曲线 - '+property.name ,
            propertyName:property.name,
            data:dataList
        }
    }
};


</script>
<style scoped lang="less">
.page-top-left {
    flex: 5;
    margin-right: 16px;
}
.page-top-right {
    flex: 11;
    .page-top-right-top {
        width: 100%;
        height: 402px;
    }
    .page-top-right-bottom {
        margin-top: 16px;
        width: 100%;
        height: 370px;
    }
}
</style>
